# Security

Child Mind Institute values the security of our users, data, and servers. We take the security of our systems seriously and encourage users to report any suspected security vulnerabilities promptly.

## Supported Versions

Only the most recent version will receive security updates.

## Reporting Vulnerabilities

To report security vulnerabilities, please do NOT use our issues page. Instead, kindly email us at dair@childmind.org. Please refrain from using other communication channels.

For non-security-related issues, we welcome your input and feedback on our issues page. Feel free to share your ideas and suggestions to help us improve our services.
